
//###########################################################################
//
// FILE:  Flash2823x_API_Config.h
//
// TITLE: F2823x Flash Algo's - User Settings
//
// NOTE:  This file contains user defined settings that
//        are used by the F2823x Flash APIs.
//
//###########################################################################
// $TI Release:$
// $Release Date:$
//###########################################################################

#ifndef PERIPHERALCONFIG_H
#define PERIPHERALCONFIG_H

#ifdef __cplusplus
extern "C" {
#endif

/*-----------------------------------------------------------------------------
CLK Config 
Clock Domain: 
CPU CLK
PLLSYSCLK

SYSCLK
PERx.SYSCLK

LSPCLK
PERx.LSPCLK

-----------------------------------------------------------------------------*/
//Osillator Clock(OSCCLK) 
//One of INTOSC1/INTOSC2/XTAL
#define CLK_SOURCE XTAL_OSC
#define CLK_SOURCE_Frequency 16000000


//System Clock(PLLSYSCLK) 
//Derived from OSCCLK,used to control registers/GS RAMs/GPIO qualification/NMI watchdog timer/CPU Timer0/1/2
//Fpllsysclk = Foscclk*(SYSPLLMULT.IMULT + SYSPLLMULT.FMULT)/SYSCLKDIVSEL.PLLSYSCLKDIV
#define PLL_IMULT  IMULT_15
#define PLL_FMULT  FMULT_0
#define PLL_SYSCLKDIV  PLLCLK_BY_2

//CPU Clock(CPUCLK) = PLLSYSCLK 
//used to clock CPU/CPU coprocessor/ CPU Private RAMs(M0M1D0D1)/boot ROM/ Flash wrapper

//SYSCLK/PERx.SYSCLK = PLLSYSCLK
//used to clock CLA/DMA/most peripherals
//Each peripheral clock has its own independent clock
//ePWM,EMIF1 EMIF2 clocks each have an additional/2 divider, disabled by PERCLKDIVSEL register

#define EPWM_CLKDIV   SYSCLK_BY_2

#define EMIF1_CLKDIV  SYSCLK_BY_1

#define EMIF2_CLKDIV  SYSCLK_BY_1



//LSPCLK/PERx.LSPCLK
//Derived from SYSCLK,used to clock SCI/SPI/McBSP
#define LSPCLKDIV  LSPCLK_BY_1


/*-----------------------------------------------------------------------------
Peripheral Clock Enable Config
-----------------------------------------------------------------------------*/
#define DISABLE  0
#define ENABLE  1

//PCLKCR0
#define CLA1_CLK		ENABLE 
#define DMA_CLK			DISABLE 
#define CPUTIMER0_CLK	ENABLE 
#define CPUTIMER1_CLK	DISABLE 
#define CPUTIMER2_CLK	DISABLE
#define HRPWM_CLK		DISABLE 
#define TBCLK_SYNC		DISABLE 


//PCLKCR1
#define EMIF1_CLK		DISABLE 
#define EMIF2_CLK		DISABLE 

//PCLKCR2
#define EPWM1_CLK		ENABLE 
#define EPWM2_CLK		ENABLE
#define EPWM3_CLK		ENABLE 
#define EPWM4_CLK		ENABLE
#define EPWM5_CLK		DISABLE 
#define EPWM6_CLK		ENABLE
#define EPWM7_CLK		DISABLE 
#define EPWM8_CLK		DISABLE
#define EPWM9_CLK		DISABLE 
#define EPWM10_CLK		DISABLE
#define EPWM11_CLK		DISABLE 
#define EPWM12_CLK		DISABLE

//PCLKCR3
#define ECAP1_CLK		ENABLE 
#define ECAP2_CLK		ENABLE 
#define ECAP3_CLK		ENABLE 
#define ECAP4_CLK		ENABLE 
#define ECAP5_CLK		DISABLE 
#define ECAP6_CLK		DISABLE 



//PCLKCR4

#define EQEP1_CLK		DISABLE 
#define EQEP2_CLK		DISABLE 
#define EQEP3_CLK		DISABLE 


//PCLKCR6
#define SD1_CLK			DISABLE 
#define SD2_CLK			DISABLE 


//PCLKCR7
#define SCIA_CLK		ENABLE 
#define SCIB_CLK		ENABLE 
#define SCIC_CLK		DISABLE 
#define SCID_CLK		DISABLE 

//PCLKCR8
#define SPIA_CLK		ENABLE 
#define SPIB_CLK		ENABLE 
#define SPIC_CLK		DISABLE 


//PCLKCR9
#define I2CA_CLK		DISABLE 
#define I2CB_CLK		DISABLE 



//PCLKCR10
#define CANA_CLK		ENABLE 
#define CANB_CLK		ENABLE 




//PCLKCR11
#define McBSPA_CLK		DISABLE 
#define McBSPB_CLK		DISABLE 
#define USBA_CLK		DISABLE 


//PCLKCR12
#define uPPA_CLK		ENABLE 


//PCLKCR13
#define ADCA_CLK		ENABLE 
#define ADCB_CLK		ENABLE 
#define ADCC_CLK		ENABLE 


//PCLKCR14
#define CMPSS1_CLK		DISABLE 
#define CMPSS2_CLK		DISABLE 
#define CMPSS3_CLK		DISABLE 
#define CMPSS4_CLK		DISABLE 
#define CMPSS5_CLK		DISABLE 
#define CMPSS6_CLK		DISABLE 
#define CMPSS7_CLK		DISABLE 
#define CMPSS8_CLK		DISABLE 

//PCLKCR16
#define DACA_CLK		ENABLE 
#define DACB_CLK		ENABLE
#define DACC_CLK		ENABLE 


/*-----------------------------------------------------------------------------
GPIO Config 
Clock Domain: PLLSYSCLK
-----------------------------------------------------------------------------*/

/*
#define GPIO_INPUT		0
#define GPIO_OUTPUT		1


//Flags for GPIO_SetupPinOptions(). The qualification flags (SYNC, QUAL3,
//QUAL6, and ASYNC) take up two bits and must be in the order specified.

//For input pins, the valid flags are:
//GPIO_PULLUP	Enable pull-up
//GPIO_INVERT	Enable input polarity inversion
//GPIO_SYNC		Synchronize the input latch to PLLSYSCLK (default -- you don't need to specify this)
//GPIO_QUAL3	Use 3-sample qualification
//GPIO_QUAL6	Use 6-sample qualification
//GPIO_ASYNC	Do not use synchronization or qualification
//(Note: only one of SYNC, QUAL3, QUAL6, or ASYNC is allowed)


//For output pins, the valid flags are:
//GPIO_OPENDRAIN	Output in open drain mode
//GPIO_PULLUP		If open drain enabled, also enable the pull-up
//and the input qualification flags (SYNC/QUAL3/QUAL6/SYNC) listed above.

*/
//#define Array(PinMuxTable,0,0)  PinMuxTable[][]
//#define PinMuxTable[0][0]   100         #define PinMuxTable[0][1]   GPIO_INPUT

/*-----------------------------------------------------------------------------
ADC Config 
Clock Domain: PERx.SYSCLK
-----------------------------------------------------------------------------*/
/*-----------ADCA--------------*/
//ʱӷƵ
#define ADCA_PRESCALE  3 

/*-----------ADCB--------------*/
#define ADCB_PRESCALE  3 


/*-----------ADCD--------------*/
#define ADCD_PRESCALE  3 

/*-----------------------------------------------------------------------------
CMPSS Config 
Clock Domain: PERx.SYSCLK
-----------------------------------------------------------------------------*/

/*-----------CMPSS1--------------*/
//Comparator
#define CMPSS1_COMPDACE  1 
#define CMPSS1_COMPHSOURCE  NEGIN_DAC 
#define CMPSS1_COMPDACREF   REFERENCE_VDDA 
#define CMPSS1_DACVAL   2048 


//Ramp Generator
#define CMPSS1_DACSOURCE  DACHVALSHADOW
#define CMPSS1_RAMPGENERATOR_SOURCE  0 //n-1 for PWMSYNCn 
#define CMPSS1_RAMPLOADSEL  RAMPMAXREFA   
#define CMPSS1_RAMPMAXREFS  2048   


//Digital Filter
#define CMPSS1_CLKPRESCALE    0x3FF
#define CMPSS1_SAMPLEWINDOW   0x1F
#define CMPSS1_THRESH         0x1F


//·
#define CMPSS1_CTRIPHSEL      CTRIP_FILTER
#define CMPSS1_CTRIPOUTHSEL   CTRIP_FILTER
#define CMPSS1_CTRIPLSEL      CTRIP_FILTER
#define CMPSS1_CTRIPOUTLSEL   CTRIP_FILTER

/*-----------CMPSS2--------------*/
//Comparator
#define CMPSS2_COMPDACE  1 
#define CMPSS2_COMPHSOURCE  NEGIN_DAC 
#define CMPSS2_COMPDACREF   REFERENCE_VDDA 
#define CMPSS2_DACVAL   2048 


//Ramp Generator
#define CMPSS2_DACSOURCE  DACHVALSHADOW
#define CMPSS2_RAMPGENERATOR_SOURCE  0 //n-1 for PWMSYNCn 
#define CMPSS2_RAMPLOADSEL  RAMPMAXREFA   
#define CMPSS2_RAMPMAXREFS  2048   


//Digital Filter
#define CMPSS2_CLKPRESCALE    0x3FF
#define CMPSS2_SAMPLEWINDOW   0x1F
#define CMPSS2_THRESH         0x1F


//·
#define CMPSS2_CTRIPHSEL      CTRIP_FILTER
#define CMPSS2_CTRIPOUTHSEL   CTRIP_FILTER
#define CMPSS2_CTRIPLSEL      CTRIP_FILTER
#define CMPSS2_CTRIPOUTLSEL   CTRIP_FILTER

/*-----------CMPSS3--------------*/
//Comparator
#define CMPSS3_COMPDACE  1 
#define CMPSS3_COMPHSOURCE  NEGIN_DAC 
#define CMPSS3_COMPDACREF   REFERENCE_VDDA 
#define CMPSS3_DACVAL   2048 


//Ramp Generator
#define CMPSS3_DACSOURCE  DACHVALSHADOW
#define CMPSS3_RAMPGENERATOR_SOURCE  0 //n-1 for PWMSYNCn 
#define CMPSS3_RAMPLOADSEL  RAMPMAXREFA   
#define CMPSS3_RAMPMAXREFS  2048   


//Digital Filter
#define CMPSS3_CLKPRESCALE    0x3FF
#define CMPSS3_SAMPLEWINDOW   0x1F
#define CMPSS3_THRESH         0x1F


//·
#define CMPSS3_CTRIPHSEL      CTRIP_FILTER
#define CMPSS3_CTRIPOUTHSEL   CTRIP_FILTER
#define CMPSS3_CTRIPLSEL      CTRIP_FILTER
#define CMPSS3_CTRIPOUTLSEL   CTRIP_FILTER

/*-----------CMPSS4--------------*/
//Comparator
#define CMPSS4_COMPDACE  1 
#define CMPSS4_COMPHSOURCE  NEGIN_DAC 
#define CMPSS4_COMPDACREF   REFERENCE_VDDA 
#define CMPSS4_DACVAL   2048 


//Ramp Generator
#define CMPSS4_DACSOURCE  DACHVALSHADOW
#define CMPSS4_RAMPGENERATOR_SOURCE  0 //n-1 for PWMSYNCn 
#define CMPSS4_RAMPLOADSEL  RAMPMAXREFA   
#define CMPSS4_RAMPMAXREFS  2048   


//Digital Filter
#define CMPSS4_CLKPRESCALE    0x3FF
#define CMPSS4_SAMPLEWINDOW   0x1F
#define CMPSS4_THRESH         0x1F


//·
#define CMPSS4_CTRIPHSEL      CTRIP_FILTER
#define CMPSS4_CTRIPOUTHSEL   CTRIP_FILTER
#define CMPSS4_CTRIPLSEL      CTRIP_FILTER
#define CMPSS4_CTRIPOUTLSEL   CTRIP_FILTER

/*-----------CMPSS5--------------*/
//Comparator
#define CMPSS5_COMPDACE  1 
#define CMPSS5_COMPHSOURCE  NEGIN_DAC 
#define CMPSS5_COMPDACREF   REFERENCE_VDDA 
#define CMPSS5_DACVAL   2048 


//Ramp Generator
#define CMPSS5_DACSOURCE  DACHVALSHADOW
#define CMPSS5_RAMPGENERATOR_SOURCE  0 //n-1 for PWMSYNCn 
#define CMPSS5_RAMPLOADSEL  RAMPMAXREFA   
#define CMPSS5_RAMPMAXREFS  2048   


//Digital Filter
#define CMPSS5_CLKPRESCALE    0x3FF
#define CMPSS5_SAMPLEWINDOW   0x1F
#define CMPSS5_THRESH         0x1F


//·
#define CMPSS5_CTRIPHSEL      CTRIP_FILTER
#define CMPSS5_CTRIPOUTHSEL   CTRIP_FILTER
#define CMPSS5_CTRIPLSEL      CTRIP_FILTER
#define CMPSS5_CTRIPOUTLSEL   CTRIP_FILTER


/*-----------CMPSS6--------------*/
//Comparator
#define CMPSS6_COMPDACE  1 
#define CMPSS6_COMPHSOURCE  NEGIN_DAC 
#define CMPSS6_COMPDACREF   REFERENCE_VDDA 
#define CMPSS6_DACVAL   2048 


//Ramp Generator
#define CMPSS6_DACSOURCE  DACHVALSHADOW
#define CMPSS6_RAMPGENERATOR_SOURCE  0 //n-1 for PWMSYNCn 
#define CMPSS6_RAMPLOADSEL  RAMPMAXREFA   
#define CMPSS6_RAMPMAXREFS  2048   


//Digital Filter
#define CMPSS6_CLKPRESCALE    0x3FF
#define CMPSS6_SAMPLEWINDOW   0x1F
#define CMPSS6_THRESH         0x1F


//·
#define CMPSS6_CTRIPHSEL      CTRIP_FILTER
#define CMPSS6_CTRIPOUTHSEL   CTRIP_FILTER
#define CMPSS6_CTRIPLSEL      CTRIP_FILTER
#define CMPSS6_CTRIPOUTLSEL   CTRIP_FILTER

/*-----------CMPSS7--------------*/
//Comparator
#define CMPSS7_COMPDACE  1 
#define CMPSS7_COMPHSOURCE  NEGIN_DAC 
#define CMPSS7_COMPDACREF   REFERENCE_VDDA 
#define CMPSS7_DACVAL   2048 


//Ramp Generator
#define CMPSS7_DACSOURCE  DACHVALSHADOW
#define CMPSS7_RAMPGENERATOR_SOURCE  0 //n-1 for PWMSYNCn 
#define CMPSS7_RAMPLOADSEL  RAMPMAXREFA   
#define CMPSS7_RAMPMAXREFS  2048   


//Digital Filter
#define CMPSS7_CLKPRESCALE    0x3FF
#define CMPSS7_SAMPLEWINDOW   0x1F
#define CMPSS7_THRESH         0x1F


//·
#define CMPSS7_CTRIPHSEL      CTRIP_FILTER
#define CMPSS7_CTRIPOUTHSEL   CTRIP_FILTER
#define CMPSS7_CTRIPLSEL      CTRIP_FILTER
#define CMPSS7_CTRIPOUTLSEL   CTRIP_FILTER

/*-----------CMPSS8--------------*/
//Comparator
#define CMPSS8_COMPDACE  1 
#define CMPSS8_COMPHSOURCE  NEGIN_DAC 
#define CMPSS8_COMPDACREF   REFERENCE_VDDA 
#define CMPSS8_DACVAL   2048 


//Ramp Generator
#define CMPSS8_DACSOURCE  DACHVALSHADOW
#define CMPSS8_RAMPGENERATOR_SOURCE  0 //n-1 for PWMSYNCn 
#define CMPSS8_RAMPLOADSEL  RAMPMAXREFA   
#define CMPSS8_RAMPMAXREFS  2048   


//Digital Filter
#define CMPSS8_CLKPRESCALE    0x3FF
#define CMPSS8_SAMPLEWINDOW   0x1F
#define CMPSS8_THRESH         0x1F


//·
#define CMPSS8_CTRIPHSEL      CTRIP_FILTER
#define CMPSS8_CTRIPOUTHSEL   CTRIP_FILTER
#define CMPSS8_CTRIPLSEL      CTRIP_FILTER
#define CMPSS8_CTRIPOUTLSEL   CTRIP_FILTER


/*-----------------------------------------------------------------------------
CAP Config 
Clock Domain: PERx.SYSCLK

-----------------------------------------------------------------------------*/
#define EC_RISING 0 
#define EC_FALLING 1 

#define EC_ABS_MODE 0 
#define EC_DELTA_MODE 1 


/*-----------CAP1--------------*/
//ʱӷƵ
#define ECAP1_PRESCALE 0 

//ѡ
#define ECAP1_CAP1POL  EC_RISING

//ģʽѡ
#define ECAP1_CTRRSETMODE  EC_ABS_MODE


/*-----------CAP2--------------*/
//ʱӷƵ
#define ECAP2_PRESCALE 0 

//ѡ
#define ECAP2_CAP1POL EC_RISING

//ģʽѡ
#define ECAP2_CTRRSETMODE  EC_ABS_MODE

/*-----------CAP3--------------*/
//ʱӷƵ
#define ECAP3_PRESCALE 0 

//ѡ
#define ECAP3_CAP1POL EC_RISING

//ģʽѡ
#define ECAP3_CTRRSETMODE  EC_ABS_MODE

/*-----------CAP4--------------*/
//ʱӷƵ
#define ECAP4_PRESCALE 0 

//ѡ
#define ECAP4_CAP1POL EC_RISING

//ģʽѡ
#define ECAP4_CTRRSETMODE  EC_ABS_MODE

/*-----------CAP5--------------*/
//ʱӷƵ
#define ECAP5_PRESCALE 0 

//ѡ
#define ECAP5_CAP1POL EC_RISING

//ģʽѡ
#define ECAP5_CTRRSETMODE  EC_ABS_MODE

/*-----------CAP6--------------*/
//ʱӷƵ
#define ECAP6_PRESCALE 0 

//ѡ
#define ECAP6_CAP1POL EC_RISING

//ģʽѡ
#define ECAP6_CTRRSETMODE  EC_ABS_MODE


/*-----------------------------------------------------------------------------
I2C Config 
Clock Domain: PERx.SYSCLK

I2C-bus clock frequecy = (I2C input clock frequency)/(IPSC + 1)[(ICCL + d)+(ICCH + d)]
	IPSC     		d
 	 0     			7
 	 1      		6
Greater than 1      5
-----------------------------------------------------------------------------*/
/*-----------I2CA--------------*/
//ӻַ
#define I2CA_SLAVE_ADDRESS 0x50


//ʱӷƵ
#define I2CA_IPSC 0x000E
#define I2CA_CLKL 60
#define I2CA_CLKH 30

//FIFO Enabel
#define I2CA_FIFOENABLE 1

/*-----------I2CB--------------*/
//ӻַ
#define I2CB_SLAVE_ADDRESS 0x50

//ʱӷƵ
#define I2CB_IPSC 0x000E
#define I2CB_CLKL 60
#define I2CB_CLKH 30

//ӻַ
#define I2CB_FIFOENABLE 1

/*-----------------------------------------------------------------------------
McBSP Config 
Clock Domain: PERx.LSPCLK

-----------------------------------------------------------------------------*/
/*-----------McBSPA--------------*/
//SPIģʽ
//0-1h: clock stop mode is disabled
//2h:Clock stop mode,without clock delya
//3h:Clock stop mode,with half-cycle colck delay

#define McBSPA_CLKSTP	0x2


//ݳ
#define McBSPA_DATALENGTH	0x0 //8_BITS 0x0
								//12_BITS 0x1
							    //16_BITS 0x2
							    //20_BITS 0x3
								//24_BITS 0x4
				 				//32_BITS 0x5



//ʱӼ֡ͬ
#define McBSPA_SRG_CLKGDV	0x0B
#define McBSPA_SRG_FWID 0



/*-----------McBSPB--------------*/
//SPIģʽ
#define McBSPB_CLKSTP	0x2

//ݳ
#define McBSPB_DATALENGTH	0x0


//ʱӼ֡ͬ
#define McBSPB_SRG_CLKGDV	0x0B
#define McBSPB_SRG_FWID 0


/*-----------------------------------------------------------------------------
SCI Config 
Clock Domain: PERx.LSPCLK

-----------------------------------------------------------------------------*/
/*-----------SCIA--------------*/
//
#define SCIA_HBAUD	0x0000
#define SCIA_LBAUD	0x00A2

//ݳ
#define SCIA_CHARLENGTH 0x07  //8 bits

//FIFOʹ
#define SCIA_FIFOENABLE 1

/*-----------SCIB--------------*/

//
#define SCIB_HBAUD	0x0000
#define SCIB_LBAUD	0x00A2

//ݳ
#define SCIB_CHARLENGTH 0x07  //8 bits

//FIFOʹ
#define SCIB_FIFOENABLE 1

/*-----------SCIC--------------*/

//
#define SCIC_HBAUD	0x0000
#define SCIC_LBAUD	0x00A2

//ݳ
#define SCIC_CHARLENGTH 0x07  //8 bits

//FIFOʹ
#define SCIC_FIFOENABLE 1


/*-----------SCID--------------*/

//
#define SCID_HBAUD	0x0000
#define SCID_LBAUD	0x00A2

//ݳ
#define SCID_CHARLENGTH 0x07  //8 bits

//FIFOʹ
#define SCID_FIFOENABLE 1


/*-----------------------------------------------------------------------------
SPI Config  
Clock Domain: PERx.LSPCLK

SPI Baud Rate = LSPCLK/(SPIBRR + 1)

SPI Clocking scheme      		 CLKPOLARITY         CLK_PHASE
Rising edge without delay            0                   0
Rising edge with delay               0                   1
Falling edge without delay           1                   0
Falling edge with delay              1                   1

-----------------------------------------------------------------------------*/
/*-----------SPIA--------------*/
//
#define SPIA_BRR 0x01

//ݳ
#define SPIA_CHARLENGTH 0x0F

//ʱӻ
#define SPIA_CLKPOLARITY 0
#define SPIA_CLK_PPHASE 0


/*-----------SPIB--------------*/
//
#define SPIB_BRR 0x01

//ݳ
#define SPIB_CHARLENGTH 0x0F

//ʱӻ
#define SPIB_CLKPOLARITY 0
#define SPIB_CLK_PPHASE 0

/*-----------SPIC--------------*/
//
#define SPIC_BRR 0x01

//ݳ
#define SPIC_CHARLENGTH 0x0F

//ʱӻ
#define SPIC_CLKPOLARITY 0
#define SPIC_CLK_PPHASE 0

/*-----------------------------------------------------------------------------
CAN Config  
Clock Domain: CAN Bit Clock

-----------------------------------------------------------------------------*/
/*-----------CANA--------------*/
//CANʱԴѡ
#define CANA_CLKSRC 0

//ʱԴƵ
#define CANA_SRCCLK 120000000

//
#define CANA_BITRATE 125000



/*-----------CANB--------------*/
//CANʱԴѡ
#define CANB_CLKSRC 0

//ʱԴƵ
#define CANB_SRCCLK 120000000

//
#define CANB_BITRATE 1000000


/*-----------------------------------------------------------------------------
PWM Config 
Clock Domain: PERx.SYSCLK

-----------------------------------------------------------------------------*/

/*-----------EPWM1--------------*/

//--TBãʱ	
#define EPWM1_TBPRD 3000
#define EPWM1_CTRMODE 	TB_COUNT_UPDOWN
#define EPWM1_SYNCOSEL  TB_CTR_ZERO
#define EPWM1_HSPCLKDIV TB_DIV1 
#define EPWM1_CLKDIV	TB_DIV1

//--CCãȽϣƥź
#define EPWM1_LOADAMODE	CC_CTR_ZERO_PRD
#define EPWM1_LOADBMODE	CC_CTR_ZERO_PRD


//--AQ
#define EPWM1_AQCTLA_CAU  AQ_SET
#define EPWM1_AQCTLA_CAD  AQ_CLEAR
#define EPWM1_AQCTLB_CBU  AQ_SET
#define EPWM1_AQCTLB_CBD  AQ_CLEAR

//--DB
#define EPWM1_DBCTL_OUTMODE  DB_DISABLE
#define EPWM1_DBCTL_POLSEL	DB_ACTV_LOC
#define EPWM1_DBRED	0x0
#define EPWM1_DBFED 0x0

//--ETã¼ģ飬¼źţģʹ
#define EPWM1_INTSEL ET_CTR_ZERO
#define EPWM1_INTEN  1
#define EPWM1_INTPRD ET_1ST

/*-----------EPWM2--------------*/
//--TBãʱ	
#define EPWM2_TBPRD 3000
#define EPWM2_CTRMODE 	TB_COUNT_UPDOWN
#define EPWM2_SYNCOSEL  TB_CTR_ZERO
#define EPWM2_HSPCLKDIV TB_DIV1 
#define EPWM2_CLKDIV	TB_DIV1

//--CCãȽϣƥź
#define EPWM2_LOADAMODE	CC_CTR_ZERO_PRD
#define EPWM2_LOADBMODE	CC_CTR_ZERO_PRD


//--AQ
#define EPWM2_AQCTLA_CAU  AQ_SET
#define EPWM2_AQCTLA_CAD  AQ_CLEAR
#define EPWM2_AQCTLB_CBU  AQ_SET
#define EPWM2_AQCTLB_CBD  AQ_CLEAR

//--DB
#define EPWM2_DBCTL_OUTMODE  DB_DISABLE
#define EPWM2_DBCTL_POLSEL	DB_ACTV_LOC
#define EPWM2_DBRED	0x0
#define EPWM2_DBFED 0x0

//--ETã¼ģ飬¼źţģʹ
#define EPWM2_INTSEL ET_CTR_ZERO
#define EPWM2_INTEN  1
#define EPWM2_INTPRD ET_1ST

/*-----------EPWM3--------------*/
//--TBãʱ	
#define EPWM3_TBPRD 3000
#define EPWM3_CTRMODE 	TB_COUNT_UPDOWN
#define EPWM3_SYNCOSEL  TB_CTR_ZERO
#define EPWM3_HSPCLKDIV TB_DIV1 
#define EPWM3_CLKDIV	TB_DIV1

//--CCãȽϣƥź
#define EPWM3_LOADAMODE	CC_CTR_ZERO_PRD
#define EPWM3_LOADBMODE	CC_CTR_ZERO_PRD


//--AQ
#define EPWM3_AQCTLA_CAU  AQ_SET
#define EPWM3_AQCTLA_CAD  AQ_CLEAR
#define EPWM3_AQCTLB_CBU  AQ_SET
#define EPWM3_AQCTLB_CBD  AQ_CLEAR

//--DB
#define EPWM3_DBCTL_OUTMODE  DB_DISABLE
#define EPWM3_DBCTL_POLSEL	DB_ACTV_LOC
#define EPWM3_DBRED	0x0
#define EPWM3_DBFED 0x0

//--ETã¼ģ飬¼źţģʹ
#define EPWM3_INTSEL ET_CTR_ZERO
#define EPWM3_INTEN  1
#define EPWM3_INTPRD ET_1ST

/*-----------EPWM4--------------*/
//--TBãʱ	
#define EPWM4_TBPRD 3000
#define EPWM4_CTRMODE 	TB_COUNT_UPDOWN
#define EPWM4_SYNCOSEL  TB_CTR_ZERO
#define EPWM4_HSPCLKDIV TB_DIV1 
#define EPWM4_CLKDIV	TB_DIV1

//--CCãȽϣƥź
#define EPWM4_LOADAMODE	CC_CTR_ZERO_PRD
#define EPWM4_LOADBMODE	CC_CTR_ZERO_PRD


//--AQ
#define EPWM4_AQCTLA_CAU  AQ_SET
#define EPWM4_AQCTLA_CAD  AQ_CLEAR
#define EPWM4_AQCTLB_CBU  AQ_SET
#define EPWM4_AQCTLB_CBD  AQ_CLEAR

//--DB
#define EPWM4_DBCTL_OUTMODE  DB_DISABLE
#define EPWM4_DBCTL_POLSEL	DB_ACTV_LOC
#define EPWM4_DBRED	0x0
#define EPWM4_DBFED 0x0

//--ETã¼ģ飬¼źţģʹ
#define EPWM4_INTSEL ET_CTR_ZERO
#define EPWM4_INTEN  1
#define EPWM4_INTPRD ET_1ST

/*-----------EPWM5--------------*/
//--TBãʱ	
#define EPWM5_TBPRD 3000
#define EPWM5_CTRMODE 	TB_COUNT_UPDOWN
#define EPWM5_SYNCOSEL  TB_CTR_ZERO
#define EPWM5_HSPCLKDIV TB_DIV1 
#define EPWM5_CLKDIV	TB_DIV1

//--CCãȽϣƥź
#define EPWM5_LOADAMODE	CC_CTR_ZERO_PRD
#define EPWM5_LOADBMODE	CC_CTR_ZERO_PRD


//--AQ
#define EPWM5_AQCTLA_CAU  AQ_SET
#define EPWM5_AQCTLA_CAD  AQ_CLEAR
#define EPWM5_AQCTLB_CBU  AQ_SET
#define EPWM5_AQCTLB_CBD  AQ_CLEAR

//--DB
#define EPWM5_DBCTL_OUTMODE  DB_DISABLE
#define EPWM5_DBCTL_POLSEL	DB_ACTV_LOC
#define EPWM5_DBRED	0x0
#define EPWM5_DBFED 0x0

//--ETã¼ģ飬¼źţģʹ
#define EPWM5_INTSEL ET_CTR_ZERO
#define EPWM5_INTEN  1
#define EPWM5_INTPRD ET_1ST

/*-----------EPWM6--------------*/
//--TBãʱ	
#define EPWM6_TBPRD 3000
#define EPWM6_CTRMODE 	TB_COUNT_UPDOWN
#define EPWM6_SYNCOSEL  TB_CTR_ZERO
#define EPWM6_HSPCLKDIV TB_DIV1 
#define EPWM6_CLKDIV	TB_DIV1

//--CCãȽϣƥź
#define EPWM6_LOADAMODE	CC_CTR_ZERO_PRD
#define EPWM6_LOADBMODE	CC_CTR_ZERO_PRD


//--AQ
#define EPWM6_AQCTLA_CAU  AQ_SET
#define EPWM6_AQCTLA_CAD  AQ_CLEAR
#define EPWM6_AQCTLB_CBU  AQ_SET
#define EPWM6_AQCTLB_CBD  AQ_CLEAR

//--DB
#define EPWM6_DBCTL_OUTMODE  DB_DISABLE
#define EPWM6_DBCTL_POLSEL	DB_ACTV_LOC
#define EPWM6_DBRED	0x0
#define EPWM6_DBFED 0x0

//--ETã¼ģ飬¼źţģʹ
#define EPWM6_INTSEL ET_CTR_ZERO
#define EPWM6_INTEN  1
#define EPWM6_INTPRD ET_1ST

/*-----------EPWM7--------------*/
//--TBãʱ	
#define EPWM7_TBPRD 3000
#define EPWM7_CTRMODE 	TB_COUNT_UPDOWN
#define EPWM7_SYNCOSEL  TB_CTR_ZERO
#define EPWM7_HSPCLKDIV TB_DIV1 
#define EPWM7_CLKDIV	TB_DIV1

//--CCãȽϣƥź
#define EPWM7_LOADAMODE	CC_CTR_ZERO_PRD
#define EPWM7_LOADBMODE	CC_CTR_ZERO_PRD


//--AQ
#define EPWM7_AQCTLA_CAU  AQ_SET
#define EPWM7_AQCTLA_CAD  AQ_CLEAR
#define EPWM7_AQCTLB_CBU  AQ_SET
#define EPWM7_AQCTLB_CBD  AQ_CLEAR

//--DB
#define EPWM7_DBCTL_OUTMODE  DB_DISABLE
#define EPWM7_DBCTL_POLSEL	DB_ACTV_LOC
#define EPWM7_DBRED	0x0
#define EPWM7_DBFED 0x0

//--ETã¼ģ飬¼źţģʹ
#define EPWM7_INTSEL ET_CTR_ZERO
#define EPWM7_INTEN  1
#define EPWM7_INTPRD ET_1ST

/*-----------EPWM8--------------*/
//--TBãʱ	
#define EPWM8_TBPRD 3000
#define EPWM8_CTRMODE 	TB_COUNT_UPDOWN
#define EPWM8_SYNCOSEL  TB_CTR_ZERO
#define EPWM8_HSPCLKDIV TB_DIV1 
#define EPWM8_CLKDIV	TB_DIV1

//--CCãȽϣƥź
#define EPWM8_LOADAMODE	CC_CTR_ZERO_PRD
#define EPWM8_LOADBMODE	CC_CTR_ZERO_PRD


//--AQ
#define EPWM8_AQCTLA_CAU  AQ_SET
#define EPWM8_AQCTLA_CAD  AQ_CLEAR
#define EPWM8_AQCTLB_CBU  AQ_SET
#define EPWM8_AQCTLB_CBD  AQ_CLEAR

//--DB
#define EPWM8_DBCTL_OUTMODE  DB_DISABLE
#define EPWM8_DBCTL_POLSEL	DB_ACTV_LOC
#define EPWM8_DBRED	0x0
#define EPWM8_DBFED 0x0

//--ETã¼ģ飬¼źţģʹ
#define EPWM8_INTSEL ET_CTR_ZERO
#define EPWM8_INTEN  1
#define EPWM8_INTPRD ET_1ST

/*-----------EPWM9--------------*/
//--TBãʱ	
#define EPWM9_TBPRD 3000
#define EPWM9_CTRMODE 	TB_COUNT_UPDOWN
#define EPWM9_SYNCOSEL  TB_CTR_ZERO
#define EPWM9_HSPCLKDIV TB_DIV1 
#define EPWM9_CLKDIV	TB_DIV1

//--CCãȽϣƥź
#define EPWM9_LOADAMODE	CC_CTR_ZERO_PRD
#define EPWM9_LOADBMODE	CC_CTR_ZERO_PRD


//--AQ
#define EPWM9_AQCTLA_CAU  AQ_SET
#define EPWM9_AQCTLA_CAD  AQ_CLEAR
#define EPWM9_AQCTLB_CBU  AQ_SET
#define EPWM9_AQCTLB_CBD  AQ_CLEAR

//--DB
#define EPWM9_DBCTL_OUTMODE  DB_DISABLE
#define EPWM9_DBCTL_POLSEL	DB_ACTV_LOC
#define EPWM9_DBRED	0x0
#define EPWM9_DBFED 0x0

//--ETã¼ģ飬¼źţģʹ
#define EPWM9_INTSEL ET_CTR_ZERO
#define EPWM9_INTEN  1
#define EPWM9_INTPRD ET_1ST

/*-----------EPWM10--------------*/
//--TBãʱ	
#define EPWM10_TBPRD 3000
#define EPWM10_CTRMODE 	TB_COUNT_UPDOWN
#define EPWM10_SYNCOSEL  TB_CTR_ZERO
#define EPWM10_HSPCLKDIV TB_DIV1 
#define EPWM10_CLKDIV	TB_DIV1

//--CCãȽϣƥź
#define EPWM10_LOADAMODE	CC_CTR_ZERO_PRD
#define EPWM10_LOADBMODE	CC_CTR_ZERO_PRD


//--AQ
#define EPWM10_AQCTLA_CAU  AQ_SET
#define EPWM10_AQCTLA_CAD  AQ_CLEAR
#define EPWM10_AQCTLB_CBU  AQ_SET
#define EPWM10_AQCTLB_CBD  AQ_CLEAR

//--DB
#define EPWM10_DBCTL_OUTMODE  DB_DISABLE
#define EPWM10_DBCTL_POLSEL	DB_ACTV_LOC
#define EPWM10_DBRED	0x0
#define EPWM10_DBFED 0x0

//--ETã¼ģ飬¼źţģʹ
#define EPWM10_INTSEL ET_CTR_ZERO
#define EPWM10_INTEN  1
#define EPWM10_INTPRD ET_1ST

/*-----------EPWM11--------------*/
//--TBãʱ	
#define EPWM11_TBPRD 3000
#define EPWM11_CTRMODE 	TB_COUNT_UPDOWN
#define EPWM11_SYNCOSEL  TB_CTR_ZERO
#define EPWM11_HSPCLKDIV TB_DIV1 
#define EPWM11_CLKDIV	TB_DIV1

//--CCãȽϣƥź
#define EPWM11_LOADAMODE	CC_CTR_ZERO_PRD
#define EPWM11_LOADBMODE	CC_CTR_ZERO_PRD


//--AQ
#define EPWM11_AQCTLA_CAU  AQ_SET
#define EPWM11_AQCTLA_CAD  AQ_CLEAR
#define EPWM11_AQCTLB_CBU  AQ_SET
#define EPWM11_AQCTLB_CBD  AQ_CLEAR

//--DB
#define EPWM11_DBCTL_OUTMODE  DB_DISABLE
#define EPWM11_DBCTL_POLSEL	DB_ACTV_LOC
#define EPWM11_DBRED	0x0
#define EPWM11_DBFED 0x0

//--ETã¼ģ飬¼źţģʹ
#define EPWM11_INTSEL ET_CTR_ZERO
#define EPWM11_INTEN  1
#define EPWM11_INTPRD ET_1ST

/*-----------EPWM12--------------*/
//--TBãʱ	
#define EPWM12_TBPRD 3000
#define EPWM12_CTRMODE 	TB_COUNT_UPDOWN
#define EPWM12_SYNCOSEL  TB_CTR_ZERO
#define EPWM12_HSPCLKDIV TB_DIV1 
#define EPWM12_CLKDIV	TB_DIV1

//--CCãȽϣƥź
#define EPWM12_LOADAMODE	CC_CTR_ZERO_PRD
#define EPWM12_LOADBMODE	CC_CTR_ZERO_PRD


//--AQ
#define EPWM12_AQCTLA_CAU  AQ_SET
#define EPWM12_AQCTLA_CAD  AQ_CLEAR
#define EPWM12_AQCTLB_CBU  AQ_SET
#define EPWM12_AQCTLB_CBD  AQ_CLEAR

//--DB
#define EPWM12_DBCTL_OUTMODE  DB_DISABLE
#define EPWM12_DBCTL_POLSEL	DB_ACTV_LOC
#define EPWM12_DBRED	0x0
#define EPWM12_DBFED 0x0

//--ETã¼ģ飬¼źţģʹ
#define EPWM12_INTSEL ET_CTR_ZERO
#define EPWM12_INTEN  1
#define EPWM12_INTPRD ET_1ST


#ifdef __cplusplus
}
#endif /* extern "C" */

#endif // -- end FLASH2823x_API_CONFIG_H 
