#include "GPIODrv.h"



void	Class_GPIODrv::Drv_InitGPIO(void)
{
    INT16 i16tmp;
    Drv_InitGpioToDefaltValue();

    Drv_GPIO_SetupPinMux(43, GPIO_MUX_CPU1, 0);
    Drv_GPIO_SetupPinOptions(43, GPIO_OUTPUT, GPIO_PUSHPULL);
			
}

void Class_GPIODrv::Drv_InitGpioToDefaltValue(void)
{
    volatile Uint32 *gpioBaseAddr;
    Uint16 regOffset;

    //Disable pin locks
    EALLOW;
    GpioCtrlRegs.GPALOCK.all = 0x00000000;
    GpioCtrlRegs.GPBLOCK.all = 0x00000000;
    GpioCtrlRegs.GPCLOCK.all = 0x00000000;
    GpioCtrlRegs.GPDLOCK.all = 0x00000000;
    GpioCtrlRegs.GPELOCK.all = 0x00000000;
    GpioCtrlRegs.GPFLOCK.all = 0x00000000;

    //Fill all registers with zeros. Writing to each register separately
    //for six GPIO modules would make this function *very* long. Fortunately,
    //we'd be writing them all with zeros anyway, so this saves a lot of space.
    gpioBaseAddr = (Uint32 *)&GpioCtrlRegs;
    for (regOffset = 0; regOffset < sizeof(GpioCtrlRegs)/2; regOffset++)
    {
        //Hack to avoid enabling pull-ups on all pins. GPyPUD is offset
        //0x0C in each register group of 0x40 words. Since this is a
        //32-bit pointer, the addresses must be divided by 2.
        if (regOffset % (0x40/2) != (0x0C/2))
            gpioBaseAddr[regOffset] = 0x00000000;
    }

    gpioBaseAddr = (Uint32 *)&GpioDataRegs;
    for (regOffset = 0; regOffset < sizeof(GpioDataRegs)/2; regOffset++)
    {
        gpioBaseAddr[regOffset] = 0x00000000;
    }

    EDIS;
}


void Class_GPIODrv::Drv_GPIO_SetupPinMux(Uint16 pin, Uint16 cpu, Uint16 peripheral)
{
    volatile Uint32 *gpioBaseAddr;
    volatile Uint32 *mux, *gmux, *csel;
    Uint16 pin32, pin16, pin8;

    pin32 = pin % 32;
    pin16 = pin % 16;
    pin8 = pin % 8;
    gpioBaseAddr = (Uint32 *)&GpioCtrlRegs + (pin/32)*GPY_CTRL_OFFSET;

    //Sanity check for valid cpu and peripheral values
    if (cpu > GPIO_MUX_CPU2CLA || peripheral > 0xF)
        return;

    //Create pointers to the appropriate registers. This is a workaround
    //for the way GPIO registers are defined. The standard definition
    //in the header file makes it very easy to do named accesses of one
    //register or bit, but hard to do arbitrary numerical accesses. It's
    //easier to have an array of GPIO modules with identical registers,
    //including arrays for multi-register groups like GPyCSEL1-4. But
    //the header file doesn't define anything we can turn into an array,
    //so manual pointer arithmetic is used instead.
    mux = gpioBaseAddr + GPYMUX + pin32/16;
    gmux = gpioBaseAddr + GPYGMUX + pin32/16;
    csel = gpioBaseAddr + GPYCSEL + pin32/8;

    //Now for the actual function
    EALLOW;

    //To change the muxing, set the peripheral mux to 0/GPIO first to avoid
    //glitches, then change the group mux, then set the peripheral mux to
    //its target value. Finally, set the CPU select. This procedure is
    //described in the TRM. Unfortunately, since we don't know the pin in
    //advance we can't hardcode a bitfield reference, so there's some tricky
    //bit twiddling here.
    *mux &= ~(0x3UL << (2*pin16));
    *gmux &= ~(0x3UL << (2*pin16));
    *gmux |= (Uint32)((peripheral >> 2) & 0x3UL) << (2*pin16);
    *mux |= (Uint32)(peripheral & 0x3UL) << (2*pin16);

    *csel &= ~(0x3L << (4*pin8));
    *csel |= (Uint32)(cpu & 0x3L) << (4*pin8);

    //WARNING: This code does not touch the analog mode select registers,
    //which are needed to give the USB module control of its IOs.

    EDIS;
}

void	Class_GPIODrv::Drv_GPIO_SetupPinValue(Uint16 pin, Uint16 pinvalue)
{
    volatile Uint32 *gpioBaseAddr;
    volatile Uint32 *value;
    Uint32 pin32, pinMask;

    pin32 = pin % 32;

    pinMask = 1UL << pin32;
    gpioBaseAddr = (Uint32 *)&GpioDataRegs + (pin/32)*GPY_DATA_OFFSET;

    //Create pointers to the appropriate registers. This is a workaround
    //for the way GPIO registers are defined. The standard definition
    //in the header file makes it very easy to do named accesses of one
    //register or bit, but hard to do arbitrary numerical accesses. It's
    //easier to have an array of GPIO modules with identical registers,
    //including arrays for multi-register groups like GPyQSEL1-2. But
    //the header file doesn't define anything we can turn into an array,
    //so manual pointer arithmetic is used instead.
    value = gpioBaseAddr + GPYDAT;


    EALLOW;

    //Set the data value
    *value &= ~pinMask;
    if (pinvalue == 1)
    {
        *value |= pinMask;
    } 
	else
    {
        *value &= ~pinMask;
    }

    EDIS;


}



void Class_GPIODrv::Drv_GPIO_SetupPinDirection(Uint16 pin, Uint16 output)
{
    volatile Uint32 *gpioBaseAddr;
    volatile Uint32 *dir;
    Uint32 pin32,pinMask;

    pin32 = pin % 32;
   // pin16 = pin % 16;
    pinMask = 1UL << pin32;
    gpioBaseAddr = (Uint32 *)&GpioCtrlRegs + (pin/32)*GPY_CTRL_OFFSET;

    //Create pointers to the appropriate registers. This is a workaround
    //for the way GPIO registers are defined. The standard definition
    //in the header file makes it very easy to do named accesses of one
    //register or bit, but hard to do arbitrary numerical accesses. It's
    //easier to have an array of GPIO modules with identical registers,
    //including arrays for multi-register groups like GPyQSEL1-2. But
    //the header file doesn't define anything we can turn into an array,
    //so manual pointer arithmetic is used instead.
    dir = gpioBaseAddr + GPYDIR;


    EALLOW;

    //Set the data direction
    *dir &= ~pinMask;
    if (output == GPIO_OUTPUT)
    {
        //Output
        *dir |= pinMask;
    } 
	else
    {
        //Input
        *dir &= ~pinMask;
    }

    EDIS;
}





void Class_GPIODrv::Drv_GPIO_SetupPinOptions(Uint16 pin, Uint16 output, Uint16 flags)
{
    volatile Uint32 *gpioBaseAddr;
    volatile Uint32 *dir, *pud, *inv, *odr, *qsel;
    Uint32 pin32, pin16, pinMask, qual;

    pin32 = pin % 32;
    pin16 = pin % 16;
    pinMask = 1UL << pin32;
    gpioBaseAddr = (Uint32 *)&GpioCtrlRegs + (pin/32)*GPY_CTRL_OFFSET;

    //Create pointers to the appropriate registers. This is a workaround
    //for the way GPIO registers are defined. The standard definition
    //in the header file makes it very easy to do named accesses of one
    //register or bit, but hard to do arbitrary numerical accesses. It's
    //easier to have an array of GPIO modules with identical registers,
    //including arrays for multi-register groups like GPyQSEL1-2. But
    //the header file doesn't define anything we can turn into an array,
    //so manual pointer arithmetic is used instead.
    dir = gpioBaseAddr + GPYDIR;
    pud = gpioBaseAddr + GPYPUD;
    inv = gpioBaseAddr + GPYINV;
    odr = gpioBaseAddr + GPYODR;
    qsel = gpioBaseAddr + GPYQSEL + pin32/16;

    EALLOW;

    //Set the data direction
    *dir &= ~pinMask;
    if (output == 1)
    {
        //Output, with optional open drain mode and pull-up
        *dir |= pinMask;

        //Enable open drain if necessary
        if (flags & GPIO_OPENDRAIN)
            *odr |= pinMask;
        else
            *odr &= ~pinMask;

        //Enable pull-up if necessary. Open drain mode must be active.
        if (flags & (GPIO_OPENDRAIN | GPIO_PULLUP))
            *pud &= ~pinMask;
        else
            *pud |= pinMask;
    } else
    {
        //Input, with optional pull-up, qualification, and polarity inversion
        *dir &= ~pinMask;

        //Enable pull-up if necessary
        if (flags & GPIO_PULLUP)
            *pud &= ~pinMask;
        else
            *pud |= pinMask;

        //Invert polarity if necessary
        if (flags & GPIO_INVERT)
            *inv |= pinMask;
        else
            *inv &= ~pinMask;
    }

    //Extract the qualification parameter and load it into the register. This is
    //also needed for open drain outputs, so we might as well do it all the time.
    qual = (flags & GPIO_ASYNC) / GPIO_QUAL3;
    *qsel &= ~(0x3L << (2 * pin16));
    if (qual != 0x0)
        *qsel |= qual << (2 * pin16);

    EDIS;
}

void Class_GPIODrv::Drv_GPIO_EnableUnbondedIOPullups(void)
{
    unsigned char pin_count = ((DevCfgRegs.PARTIDL.all & 0x00000700) >> 8) ; //bits 8-10 have pin count*/
/*
 * 5 = 100 pin
 * 6 = 176 pin
 * 7 = 337 pin
 */

    if(pin_count == 5)
    {
        EALLOW;
        GpioCtrlRegs.GPAPUD.all = ~0xFFC003E3;  //GPIOs 0-1, 5-9, 22-31
        GpioCtrlRegs.GPBPUD.all = ~0x03FFF1FF;  //GPIOs 32-40, 44-57
        GpioCtrlRegs.GPCPUD.all = ~0xE10FBC18;  //GPIOs 67-68, 74-77, 79-83, 93-95
        GpioCtrlRegs.GPDPUD.all = ~0xFFFFFFF7;  //GPIOs 96-127
        GpioCtrlRegs.GPEPUD.all = ~0xFFFFFFFF;  //GPIOs 128-159
        GpioCtrlRegs.GPFPUD.all = ~0x000001FF;  //GPIOs 160-168
        EDIS;
    }
    else if (pin_count == 6)
    {
		EALLOW;
		GpioCtrlRegs.GPCPUD.all = ~0x80000000;	//GPIO 95
		GpioCtrlRegs.GPDPUD.all = ~0xFFFFFFF7;	//GPIOs 96-127
		GpioCtrlRegs.GPEPUD.all = ~0xFFFFFFDF;	//GPIOs 128-159 except for 133
		GpioCtrlRegs.GPFPUD.all = ~0x000001FF;	//GPIOs 160-168
		EDIS;

    }
    else
    {
        //do nothing - this is 337 pin package
    }

}

// FPGARESETź
inline  void    Class_GPIODrv::Drv_GPIO_FPGAReset(void)
{
    GpioDataRegs.GPBCLEAR.bit.GPIO53 = 1;
}


//FPGARESETź
inline  void    Class_GPIODrv::Drv_GPIO_FPGAResetClear(void)
{
    GpioDataRegs.GPBSET.bit.GPIO53 = 1;
}

void Class_GPIODrv::InitECap1Gpio(Uint16 pin)
{
	EALLOW;
	InputXbarRegs.INPUT7SELECT = pin; 		// Set eCAP1 source to GPIO-66
	EDIS;
}

void Class_GPIODrv::InitECap2Gpio(Uint16 pin)
{
	EALLOW;
	InputXbarRegs.INPUT8SELECT = pin; 		// Set eCAP2 source to GPIO-67
	EDIS;
}

void Class_GPIODrv::InitECap3Gpio(Uint16 pin)
{
	EALLOW;
	InputXbarRegs.INPUT9SELECT = pin; 		// Set eCAP3 source to GPIO-26
	EDIS;
}

void Class_GPIODrv::InitECap4Gpio(Uint16 pin)
{
	EALLOW;
	InputXbarRegs.INPUT10SELECT = pin; 		// Set eCAP4 source to GPIO-27
	EDIS;
}



//============================================================
// End of file.
//============================================================
