#include "SysDrv.h"



interrupt void EPWM1_PERIOD_INT_ISR(void);
interrupt void c_int5(void);


interrupt void PIE_RESERVED(void)
 {


    EALLOW;
    WdRegs.WDCR.all = 0x0028;
    EDIS;

    while(1)
    {
        ;//wait for watchdog reset
    }
}


void	Class_SysDrv::Drv_SysCtrlInit(void)
{
		// Disable the watchdog
	   objWatchDogDrv.Drv_DisableDog();
	
	
	// Copy time critical code and Flash setup code to RAM
	// This includes the following functions:  InitFlash();
	// The	RamfuncsLoadStart, RamfuncsLoadSize, and RamfuncsRunStart
	// symbols are created by the linker. Refer to the device .cmd file.
		objRAMDrv.Drv_MemCopy(&RamfuncsLoadStart, &RamfuncsLoadEnd, &RamfuncsRunStart);
	//    memcpy(&RamfuncsRunStart, &RamfuncsLoadStart, (size_t)&RamfuncsLoadSize);
	// Call Flash Initialization to setup flash waitstates
	// This function must reside in RAM
		//objFlashDrv.Drv_InitFlash();
	
	
		// *IMPORTANT*
		// The Device_cal function, which copies the ADC & oscillator calibration values
		// from TI reserved OTP into the appropriate trim registers, occurs automatically
		// in the Boot ROM. If the boot ROM code is bypassed during the debug process, the
		// following function MUST be called for the ADC and oscillators to function according
		// to specification. The clocks to the ADC MUST be enabled before calling this
		// function.
		// See the device data manual and/or the ADC Reference
		// Manual for more information.
	
		EALLOW;
	
		//enable pull-ups on unbonded IOs as soon as possible to reduce power consumption.
		objGPIODrv.Drv_GPIO_EnableUnbondedIOPullups();
	
		CpuSysRegs.PCLKCR13.bit.ADC_A = 1;
		CpuSysRegs.PCLKCR13.bit.ADC_B = 1;
		CpuSysRegs.PCLKCR13.bit.ADC_D = 1;
	
		//check if device is trimmed
		/*if(*((Uint16 *)0x5D1B6) == 0x0000){
			//device is not trimmed, apply static calibration values
			AnalogSubsysRegs.ANAREFTRIMA.all = 31709;
			AnalogSubsysRegs.ANAREFTRIMB.all = 31709;
			AnalogSubsysRegs.ANAREFTRIMD.all = 31709;
		}*/
	
		CpuSysRegs.PCLKCR13.bit.ADC_A = 0;
		CpuSysRegs.PCLKCR13.bit.ADC_B = 0;
		CpuSysRegs.PCLKCR13.bit.ADC_D = 0;
		EDIS;
	
		// Initialize the PLL control: PLLCR and CLKINDIV
		// F28_PLLCR and F28_CLKINDIV are defined in F2807x_Examples.h
		// Note: The internal oscillator CANNOT be used as the PLL source if the
		// PLLSYSCLK is configured to frequencies above 194 MHz.
		objSysDrv.Drv_InitSysPll(XTAL_OSC,IMULT_12,FMULT_0,PLLCLK_BY_2);    // 120M  for 20M OSC
	
		//Turn on all peripherals
		objSysDrv.Drv_InitPeripheralClocks();

}

void	Class_SysDrv::Drv_InitSysPll(Uint16 clock_source, Uint16 imult, Uint16 fmult, Uint16 divsel)
{
    if((clock_source == ClkCfgRegs.CLKSRCCTL1.bit.OSCCLKSRCSEL)    &&
      (imult         == ClkCfgRegs.SYSPLLMULT.bit.IMULT)           &&
      (fmult         == ClkCfgRegs.SYSPLLMULT.bit.FMULT)           &&
      (divsel        == ClkCfgRegs.SYSCLKDIVSEL.bit.PLLSYSCLKDIV))
    {
        //everything is set as required, so just return
        return;
    }

    if(clock_source != ClkCfgRegs.CLKSRCCTL1.bit.OSCCLKSRCSEL)
    {
        switch (clock_source)
        {
            case INT_OSC1:
                Drv_SysIntOsc1Sel();
                break;

            case INT_OSC2:
                Drv_SysIntOsc2Sel();
                break;

            case XTAL_OSC:
               	Drv_SysXtalOscSel();
                break;
        }
    }

    EALLOW;
     // first modify the PLL multipliers
    if(imult != ClkCfgRegs.SYSPLLMULT.bit.IMULT || fmult != ClkCfgRegs.SYSPLLMULT.bit.FMULT)
    {
        // Bypass PLL and set dividers to /1
        ClkCfgRegs.SYSPLLCTL1.bit.PLLCLKEN = 0;
        ClkCfgRegs.SYSCLKDIVSEL.bit.PLLSYSCLKDIV = 0;

        // Program PLL multipliers
        Uint32 temp_syspllmult = ClkCfgRegs.SYSPLLMULT.all;
        ClkCfgRegs.SYSPLLMULT.all = ((temp_syspllmult & ~(0x37FU)) | 
                                     ((fmult << 8U) | imult));
                                     
        ClkCfgRegs.SYSPLLCTL1.bit.PLLEN = 1;            // Enable SYSPLL

        // Wait for the SYSPLL lock
        while(ClkCfgRegs.SYSPLLSTS.bit.LOCKS != 1)
        {
            // Uncomment to service the watchdog
            // ServiceDog();
        }

        // Write a multiplier again to ensure proper PLL initialization
        // This will force the PLL to lock a second time
        ClkCfgRegs.SYSPLLMULT.bit.IMULT = imult;        // Setting integer multiplier

        // Wait for the SYSPLL re-lock
        while(ClkCfgRegs.SYSPLLSTS.bit.LOCKS != 1)
        {
            // Uncomment to service the watchdog
            // ServiceDog();
        }
    }

    // Set divider to produce slower output frequency to limit current increase
    if(divsel != PLLCLK_BY_126)
    {
         ClkCfgRegs.SYSCLKDIVSEL.bit.PLLSYSCLKDIV = divsel + 1;
    }else
    {
         ClkCfgRegs.SYSCLKDIVSEL.bit.PLLSYSCLKDIV = divsel;
    }

    // Enable PLLSYSCLK is fed from system PLL clock
    ClkCfgRegs.SYSPLLCTL1.bit.PLLCLKEN = 1;

    // Small 100 cycle delay
    asm(" RPT #100 || NOP");

    // Set the divider to user value
    ClkCfgRegs.SYSCLKDIVSEL.bit.PLLSYSCLKDIV = divsel;


    EDIS;
}


// This function switches to Internal Oscillator 1 and turns off all other clock
// sources to minimize power consumption

void Class_SysDrv::Drv_SysIntOsc1Sel (void) {
    EALLOW;
    ClkCfgRegs.CLKSRCCTL1.bit.OSCCLKSRCSEL = 2; // Clk Src = INTOSC1
    EDIS;
}


// This function switches to Internal oscillator 2 from External Oscillator
// and turns off all other clock sources to minimize power consumption
// NOTE: If there is no external clock connection, when switching from
//       INTOSC1 to INTOSC2, EXTOSC and XLCKIN must be turned OFF prior
//       to switching to internal oscillator 1

void Class_SysDrv::Drv_SysIntOsc2Sel (void) {

    EALLOW;
    ClkCfgRegs.CLKSRCCTL1.bit.INTOSC2OFF=0;     // Turn on INTOSC2
    ClkCfgRegs.CLKSRCCTL1.bit.OSCCLKSRCSEL = 0; // Clk Src = INTOSC2
    EDIS;

}


// This function switches to External CRYSTAL oscillator and turns off all other clock
// sources to minimize power consumption. This option may not be available on all
// device packages

void Class_SysDrv::Drv_SysXtalOscSel (void)  {

    EALLOW;
    ClkCfgRegs.CLKSRCCTL1.bit.XTALOFF=0;        // Turn on XTALOSC
    ClkCfgRegs.CLKSRCCTL1.bit.OSCCLKSRCSEL = 1; // Clk Src = XTAL
    EDIS;

}



//This function initializes the clocks to the peripheral modules.
void	Class_SysDrv::Drv_InitPeripheralClocks(void)		
{
	EALLOW;

	//EPWMʱdivider
	ClkCfgRegs.PERCLKDIVSEL.bit.EPWMCLKDIV = EPWM_CLKDIV; // PLLSYSCLK/2= 60M

	//ʱ
      //ClkCfgRegs.LOSPCP.bit.LSPCLKDIV = 0x2;  // 010 on reset
      ClkCfgRegs.LOSPCP.all = 2;//LSPCLKDIV;  // SYSCLKOUT/1 (120M)
      
	CpuSysRegs.PCLKCR0.bit.CLA1 = CLA1_CLK;
	CpuSysRegs.PCLKCR0.bit.DMA = DMA_CLK;
	CpuSysRegs.PCLKCR0.bit.CPUTIMER0 = CPUTIMER0_CLK;
	CpuSysRegs.PCLKCR0.bit.CPUTIMER1 = CPUTIMER1_CLK;
	CpuSysRegs.PCLKCR0.bit.CPUTIMER2 = CPUTIMER2_CLK;
	CpuSysRegs.PCLKCR0.bit.HRPWM = HRPWM_CLK;
	CpuSysRegs.PCLKCR0.bit.TBCLKSYNC = TBCLK_SYNC;

	CpuSysRegs.PCLKCR1.bit.EMIF1 = EMIF1_CLK;
	CpuSysRegs.PCLKCR1.bit.EMIF2 = EMIF2_CLK;

	CpuSysRegs.PCLKCR2.bit.EPWM1 = EPWM1_CLK;
	CpuSysRegs.PCLKCR2.bit.EPWM2 = EPWM2_CLK;
	CpuSysRegs.PCLKCR2.bit.EPWM3 = EPWM3_CLK;
	CpuSysRegs.PCLKCR2.bit.EPWM4 = EPWM4_CLK;
	CpuSysRegs.PCLKCR2.bit.EPWM5 = EPWM5_CLK;
	CpuSysRegs.PCLKCR2.bit.EPWM6 = EPWM6_CLK;
	CpuSysRegs.PCLKCR2.bit.EPWM7 = EPWM7_CLK;
	CpuSysRegs.PCLKCR2.bit.EPWM8 = EPWM8_CLK;
	CpuSysRegs.PCLKCR2.bit.EPWM9 = EPWM9_CLK;
	CpuSysRegs.PCLKCR2.bit.EPWM10 = EPWM10_CLK;
	CpuSysRegs.PCLKCR2.bit.EPWM11 = EPWM11_CLK;
	CpuSysRegs.PCLKCR2.bit.EPWM12 = EPWM12_CLK;

	CpuSysRegs.PCLKCR3.bit.ECAP1 = ECAP1_CLK;
	CpuSysRegs.PCLKCR3.bit.ECAP2 = ECAP2_CLK;
	CpuSysRegs.PCLKCR3.bit.ECAP3 = ECAP3_CLK;
	CpuSysRegs.PCLKCR3.bit.ECAP4 = ECAP4_CLK;
	CpuSysRegs.PCLKCR3.bit.ECAP5 = ECAP5_CLK;
	CpuSysRegs.PCLKCR3.bit.ECAP6 = ECAP6_CLK;

	CpuSysRegs.PCLKCR4.bit.EQEP1 = EQEP1_CLK;
	CpuSysRegs.PCLKCR4.bit.EQEP2 = EQEP2_CLK;
	CpuSysRegs.PCLKCR4.bit.EQEP3 = EQEP3_CLK;

	CpuSysRegs.PCLKCR6.bit.SD1 = SD1_CLK;
	CpuSysRegs.PCLKCR6.bit.SD2 = SD2_CLK;

	CpuSysRegs.PCLKCR7.bit.SCI_A = SCIA_CLK;
	CpuSysRegs.PCLKCR7.bit.SCI_B = SCIB_CLK;
	CpuSysRegs.PCLKCR7.bit.SCI_C = SCIC_CLK;
	CpuSysRegs.PCLKCR7.bit.SCI_D = SCID_CLK;

	CpuSysRegs.PCLKCR8.bit.SPI_A = SPIA_CLK;
	CpuSysRegs.PCLKCR8.bit.SPI_B = SPIB_CLK;
	CpuSysRegs.PCLKCR8.bit.SPI_C = SPIC_CLK;

	CpuSysRegs.PCLKCR9.bit.I2C_A = I2CA_CLK;
	CpuSysRegs.PCLKCR9.bit.I2C_B = I2CB_CLK;

	CpuSysRegs.PCLKCR10.bit.CAN_A = CANA_CLK;
	CpuSysRegs.PCLKCR10.bit.CAN_B = CANB_CLK;

	CpuSysRegs.PCLKCR11.bit.McBSP_A = McBSPA_CLK;
	CpuSysRegs.PCLKCR11.bit.McBSP_B = McBSPB_CLK;
	CpuSysRegs.PCLKCR11.bit.USB_A = USBA_CLK;

	CpuSysRegs.PCLKCR13.bit.ADC_A = ADCA_CLK;
	CpuSysRegs.PCLKCR13.bit.ADC_B = ADCB_CLK;
	CpuSysRegs.PCLKCR13.bit.ADC_D = ADCC_CLK;

	CpuSysRegs.PCLKCR14.bit.CMPSS1 = CMPSS1_CLK;
	CpuSysRegs.PCLKCR14.bit.CMPSS2 = CMPSS2_CLK;
	CpuSysRegs.PCLKCR14.bit.CMPSS3 = CMPSS3_CLK;
	CpuSysRegs.PCLKCR14.bit.CMPSS4 = CMPSS4_CLK;
	CpuSysRegs.PCLKCR14.bit.CMPSS5 = CMPSS5_CLK;
	CpuSysRegs.PCLKCR14.bit.CMPSS6 = CMPSS6_CLK;
	CpuSysRegs.PCLKCR14.bit.CMPSS7 = CMPSS7_CLK;
	CpuSysRegs.PCLKCR14.bit.CMPSS8 = CMPSS8_CLK;

	CpuSysRegs.PCLKCR16.bit.DAC_A = DACA_CLK;
	CpuSysRegs.PCLKCR16.bit.DAC_B = DACB_CLK;
	CpuSysRegs.PCLKCR16.bit.DAC_C = DACC_CLK;
	
	EDIS;
}



//This function initializes the PIE control registers to a known state.
void	Class_SysDrv::Drv_InitPieCtrl(void)		
{
    // Disable Interrupts at the CPU level:
    DINT;

    // Disable the PIE
    PieCtrlRegs.PIECTRL.bit.ENPIE = 0;

	// Clear all PIEIER registers:
	PieCtrlRegs.PIEIER1.all = 0;
	PieCtrlRegs.PIEIER2.all = 0;
       PieCtrlRegs.PIEIER3.bit.INTx1 = 1;       // Enable EPWM1 Interrupt
	PieCtrlRegs.PIEIER4.all = 0;
	PieCtrlRegs.PIEIER5.all = 0;
	PieCtrlRegs.PIEIER6.all = 0;
	PieCtrlRegs.PIEIER7.all = 0;
	PieCtrlRegs.PIEIER8.all = 0;
//  PieCtrlRegs.PIEIER9.all = 3;            // Enable SCI-A TXD&RXD Interrupt
    PieCtrlRegs.PIEIER9.bit.INTx5 = 1;          // Enable eCAN A0
	PieCtrlRegs.PIEIER10.all = 0;
	PieCtrlRegs.PIEIER11.all = 0;
	PieCtrlRegs.PIEIER12.all = 0;

	// Clear all PIEIFR registers:
	PieCtrlRegs.PIEIFR1.all = 0;
	PieCtrlRegs.PIEIFR2.all = 0;
	PieCtrlRegs.PIEIFR3.all = 0;	
	PieCtrlRegs.PIEIFR4.all = 0;
	PieCtrlRegs.PIEIFR5.all = 0;
	PieCtrlRegs.PIEIFR6.all = 0;
	PieCtrlRegs.PIEIFR7.all = 0;
	PieCtrlRegs.PIEIFR8.all = 0;
    PieCtrlRegs.PIEIFR9.all = 0;
	PieCtrlRegs.PIEIFR10.all = 0;
	PieCtrlRegs.PIEIFR11.all = 0;
	PieCtrlRegs.PIEIFR12.all = 0;

}

const struct PIE_VECT_TABLE PieVectTableInit = {
    (PINT)PIE_RESERVED_ISR,                                 // Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // Reserved 
    (PINT)TIMER1_ISR,                                       // CPU Timer 1 Interrupt 
    (PINT)TIMER2_ISR,                                       // CPU Timer 2 Interrupt 
    (PINT)DATALOG_ISR,                                      // Datalogging Interrupt 
    (PINT)RTOS_ISR,                                         // RTOS Interrupt 
    (PINT)EMU_ISR,                                          // Emulation Interrupt 
    (PINT)NMI_ISR,                                          // Non-Maskable Interrupt 
    (PINT)ILLEGAL_ISR,                                      // Illegal Operation Trap 
    (PINT)USER1_ISR,                                        // User Defined Trap 1 
    (PINT)USER2_ISR,                                        // User Defined Trap 2 
    (PINT)USER3_ISR,                                        // User Defined Trap 3 
    (PINT)USER4_ISR,                                        // User Defined Trap 4 
    (PINT)USER5_ISR,                                        // User Defined Trap 5 
    (PINT)USER6_ISR,                                        // User Defined Trap 6 
    (PINT)USER7_ISR,                                        // User Defined Trap 7 
    (PINT)USER8_ISR,                                        // User Defined Trap 8 
    (PINT)USER9_ISR,                                        // User Defined Trap 9 
    (PINT)USER10_ISR,                                       // User Defined Trap 10 
    (PINT)USER11_ISR,                                       // User Defined Trap 11 
    (PINT)USER12_ISR,                                       // User Defined Trap 12 
    (PINT)ADCA1_ISR,                                        // 1.1 - ADCA Interrupt 1 
    (PINT)ADCB1_ISR,                                        // 1.2 - ADCB Interrupt 1 
    (PINT)PIE_RESERVED_ISR,                                 // 1.3 - Reserved 
    (PINT)XINT1_ISR,                                        // 1.4 - XINT1 Interrupt 
    (PINT)XINT2_ISR,                                        // 1.5 - XINT2 Interrupt 
    (PINT)ADCD1_ISR,                                        // 1.6 - ADCD Interrupt 1 
    (PINT)TIMER0_ISR,                                       // 1.7 - Timer 0 Interrupt 
    (PINT)WAKE_ISR,                                         // 1.8 - Standby and Halt Wakeup Interrupt 
    (PINT)EPWM1_TZ_ISR,                                     // 2.1 - ePWM1 Trip Zone Interrupt 
    (PINT)EPWM2_TZ_ISR,                                     // 2.2 - ePWM2 Trip Zone Interrupt 
    (PINT)EPWM3_TZ_ISR,                                     // 2.3 - ePWM3 Trip Zone Interrupt 
    (PINT)EPWM4_TZ_ISR,                                     // 2.4 - ePWM4 Trip Zone Interrupt 
    (PINT)EPWM5_TZ_ISR,                                     // 2.5 - ePWM5 Trip Zone Interrupt 
    (PINT)EPWM6_TZ_ISR,                                     // 2.6 - ePWM6 Trip Zone Interrupt 
    (PINT)EPWM7_TZ_ISR,                                     // 2.7 - ePWM7 Trip Zone Interrupt 
    (PINT)EPWM8_TZ_ISR,                                     // 2.8 - ePWM8 Trip Zone Interrupt 
    (PINT)EPWM_INT_ISR,                                      // 3.1 - ePWM1 Interrupt 
    //(PINT)EPWM1_ISR,                                        // 3.1 - ePWM1 Interrupt 
    (PINT)EPWM2_ISR,                                        // 3.2 - ePWM2 Interrupt 
    (PINT)EPWM3_ISR,                                        // 3.3 - ePWM3 Interrupt 
    (PINT)EPWM4_ISR,                                        // 3.4 - ePWM4 Interrupt 
    (PINT)EPWM5_ISR,                                        // 3.5 - ePWM5 Interrupt 
    (PINT)EPWM6_ISR,                                        // 3.6 - ePWM6 Interrupt 
    (PINT)EPWM7_ISR,                                        // 3.7 - ePWM7 Interrupt 
    (PINT)EPWM8_ISR,                                        // 3.8 - ePWM8 Interrupt 
    (PINT)ECAP1_ISR,                                        // 4.1 - eCAP1 Interrupt 
    (PINT)ECAP2_ISR,                                        // 4.2 - eCAP2 Interrupt 
    (PINT)ECAP3_ISR,                                        // 4.3 - eCAP3 Interrupt 
    (PINT)ECAP4_ISR,                                        // 4.4 - eCAP4 Interrupt 
    (PINT)ECAP5_ISR,                                        // 4.5 - eCAP5 Interrupt 
    (PINT)ECAP6_ISR,                                        // 4.6 - eCAP6 Interrupt 
    (PINT)PIE_RESERVED_ISR,                                 // 4.7 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 4.8 - Reserved 
    (PINT)EQEP1_ISR,                                        // 5.1 - eQEP1 Interrupt 
    (PINT)EQEP2_ISR,                                        // 5.2 - eQEP2 Interrupt 
    (PINT)EQEP3_ISR,                                        // 5.3 - eQEP3 Interrupt 
    (PINT)PIE_RESERVED_ISR,                                 // 5.4 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 5.5 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 5.6 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 5.7 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 5.8 - Reserved 
   (PINT)SPIA_RX_ISR,                                      // 6.1 - SPIA Receive Interrupt 
    (PINT)SPIA_TX_ISR,                                      // 6.2 - SPIA Transmit Interrupt 
    (PINT)SPIB_RX_ISR,                                      // 6.3 - SPIB Receive Interrupt 
    (PINT)SPIB_TX_ISR,                                      // 6.4 - SPIB Transmit Interrupt 
    (PINT)MCBSPA_RX_ISR,                                    // 6.5 - McBSPA Receive Interrupt 
    (PINT)MCBSPA_TX_ISR,                                    // 6.6 - McBSPA Transmit Interrupt 
    (PINT)MCBSPB_RX_ISR,                                    // 6.7 - McBSPB Receive Interrupt 
    (PINT)MCBSPB_TX_ISR,                                    // 6.8 - McBSPB Transmit Interrupt 
    (PINT)DMA_CH1_ISR,                                      // 7.1 - DMA Channel 1 Interrupt 
    (PINT)DMA_CH2_ISR,                                      // 7.2 - DMA Channel 2 Interrupt 
    (PINT)DMA_CH3_ISR,                                      // 7.3 - DMA Channel 3 Interrupt 
    (PINT)DMA_CH4_ISR,                                      // 7.4 - DMA Channel 4 Interrupt 
    (PINT)DMA_CH5_ISR,                                      // 7.5 - DMA Channel 5 Interrupt 
    (PINT)DMA_CH6_ISR,                                      // 7.6 - DMA Channel 6 Interrupt 
    (PINT)PIE_RESERVED_ISR,                                 // 7.7 - Reserved 
   (PINT)PIE_RESERVED_ISR,                                 // 7.8 - Reserved 
    (PINT)I2CA_ISR,                                         // 8.1 - I2CA Interrupt 1 
    (PINT)I2CA_FIFO_ISR,                                    // 8.2 - I2CA Interrupt 2 
    (PINT)I2CB_ISR,                                         // 8.3 - I2CB Interrupt 1 
    (PINT)I2CB_FIFO_ISR,                                    // 8.4 - I2CB Interrupt 2 
    (PINT)SCIC_RX_ISR,                                      // 8.5 - SCIC Receive Interrupt 
    (PINT)SCIC_TX_ISR,                                      // 8.6 - SCIC Transmit Interrupt 
    (PINT)SCID_RX_ISR,                                      // 8.7 - SCID Receive Interrupt 
    (PINT)SCID_TX_ISR,                                      // 8.8 - SCID Transmit Interrupt 
    (PINT)SCIA_RX_ISR,                                      // 9.1 - SCIA Receive Interrupt 
    (PINT)SCIA_TX_ISR,                                      // 9.2 - SCIA Transmit Interrupt 
    (PINT)SCIB_RX_ISR,                                      // 9.3 - SCIB Receive Interrupt 
    (PINT)SCIB_TX_ISR,                                      // 9.4 - SCIB Transmit Interrupt 
    //(PINT)ECAN0INTA_ISR,                                        // 9.5 - CANA Interrupt 0
    (PINT)CANA1_ISR,                                        // 9.6 - CANA Interrupt 1
    (PINT)CANB0_ISR,                                        // 9.7 - CANB Interrupt 0
    (PINT)CANB1_ISR,                                        // 9.8 - CANB Interrupt 1
    (PINT)ADCA_EVT_ISR,                                     // 10.1 - ADCA Event Interrupt 
    (PINT)ADCA2_ISR,                                        // 10.2 - ADCA Interrupt 2 
    (PINT)ADCA3_ISR,                                        // 10.3 - ADCA Interrupt 3 
    (PINT)ADCA4_ISR,                                        // 10.4 - ADCA Interrupt 4 
    (PINT)ADCB_EVT_ISR,                                     // 10.5 - ADCB Event Interrupt 
    (PINT)ADCB2_ISR,                                        // 10.6 - ADCB Interrupt 2 
    (PINT)ADCB3_ISR,                                        // 10.7 - ADCB Interrupt 3 
    (PINT)ADCB4_ISR,                                        // 10.8 - ADCB Interrupt 4 
    (PINT)CLA1_1_ISR,                                       // 11.1 - CLA1 Interrupt 1 
    (PINT)CLA1_2_ISR,                                       // 11.2 - CLA1 Interrupt 2 
    (PINT)CLA1_3_ISR,                                       // 11.3 - CLA1 Interrupt 3 
    (PINT)CLA1_4_ISR,                                       // 11.4 - CLA1 Interrupt 4 
    (PINT)CLA1_5_ISR,                                       // 11.5 - CLA1 Interrupt 5 
    (PINT)CLA1_6_ISR,                                       // 11.6 - CLA1 Interrupt 6 
    (PINT)CLA1_7_ISR,                                       // 11.7 - CLA1 Interrupt 7 
    (PINT)CLA1_8_ISR,                                       // 11.8 - CLA1 Interrupt 8 
    (PINT)XINT3_ISR,                                        // 12.1 - XINT3 Interrupt 
    (PINT)XINT4_ISR,                                        // 12.2 - XINT4 Interrupt 
    (PINT)XINT5_ISR,                                        // 12.3 - XINT5 Interrupt 
    (PINT)PIE_RESERVED_ISR,                                 // 12.4 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 12.5 - Reserved 
    (PINT)VCU_ISR,                                          // 12.6 - VCU Interrupt 
    (PINT)FPU_OVERFLOW_ISR,                                 // 12.7 - FPU Overflow Interrupt 
    (PINT)FPU_UNDERFLOW_ISR,                                // 12.8 - FPU Underflow Interrupt 
    (PINT)PIE_RESERVED_ISR,                                 // 1.9 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 1.10 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 1.11 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 1.12 - Reserved 
    (PINT)IPC0_ISR,                                         // 1.13 - IPC Interrupt 0 
    (PINT)IPC1_ISR,                                         // 1.14 - IPC Interrupt 1 
    (PINT)IPC2_ISR,                                         // 1.15 - IPC Interrupt 2 
    (PINT)IPC3_ISR,                                         // 1.16 - IPC Interrupt 3 
    (PINT)EPWM9_TZ_ISR,                                     // 2.9 - ePWM9 Trip Zone Interrupt 
    (PINT)EPWM10_TZ_ISR,                                    // 2.10 - ePWM10 Trip Zone Interrupt 
    (PINT)EPWM11_TZ_ISR,                                    // 2.11 - ePWM11 Trip Zone Interrupt 
    (PINT)EPWM12_TZ_ISR,                                    // 2.12 - ePWM12 Trip Zone Interrupt 
    (PINT)PIE_RESERVED_ISR,                                 // 2.13 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 2.14 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 2.15 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 2.16 - Reserved 
    (PINT)EPWM9_ISR,                                        // 3.9 - ePWM9 Interrupt 
    (PINT)EPWM10_ISR,                                       // 3.10 - ePWM10 Interrupt 
    (PINT)EPWM11_ISR,                                       // 3.11 - ePWM11 Interrupt 
    (PINT)EPWM12_ISR,                                       // 3.12 - ePWM12 Interrupt 
    (PINT)PIE_RESERVED_ISR,                                 // 3.13 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 3.14 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 3.15 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 3.16 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 4.9 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 4.10 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 4.11 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 4.12 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 4.13 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 4.14 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 4.15 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 4.16 - Reserved 
    (PINT)SD1_ISR,                                          // 5.9 - SD1 Interrupt 
    (PINT)SD2_ISR,                                          // 5.10 - SD2 Interrupt 
    (PINT)PIE_RESERVED_ISR,                                 // 5.11 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 5.12 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 5.13 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 5.14 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 5.15 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 5.16 - Reserved 
    (PINT)SPIC_RX_ISR,                                      // 6.9 - SPIC Receive Interrupt 
    (PINT)SPIC_TX_ISR,                                      // 6.10 - SPIC Transmit Interrupt 
    (PINT)PIE_RESERVED_ISR,                                 // 6.11 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 6.12 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 6.13 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 6.14 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 6.15 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 6.16 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 7.9 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 7.10 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 7.11 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 7.12 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 7.13 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 7.14 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 7.15 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 7.16 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 8.9 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 8.10 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 8.11 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 8.12 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 8.13 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 8.14 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 8.15 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 8.16 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 9.9 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 9.10 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 9.11 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 9.12 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 9.13 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 9.14 - Reserved 
    (PINT)USBA_ISR,                                         // 9.15 - USBA Interrupt 
    (PINT)PIE_RESERVED_ISR,                                 // 9.16 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 10.9 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 10.10 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 10.11 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 10.12 - Reserved 
    (PINT)ADCD_EVT_ISR,                                     // 10.13 - ADCD Event Interrupt 
    (PINT)ADCD2_ISR,                                        // 10.14 - ADCD Interrupt 2 
    (PINT)ADCD3_ISR,                                        // 10.15 - ADCD Interrupt 3 
    (PINT)ADCD4_ISR,                                        // 10.16 - ADCD Interrupt 4 
    (PINT)PIE_RESERVED_ISR,                                 // 11.9 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 11.10 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 11.11 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 11.12 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 11.13 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 11.14 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 11.15 - Reserved 
    (PINT)PIE_RESERVED_ISR,                                 // 11.16 - Reserved 
    (PINT)EMIF_ERROR_ISR,                                   // 12.9 - EMIF Error Interrupt 
    (PINT)RAM_CORRECTABLE_ERROR_ISR,                        // 12.10 - RAM Correctable Error Interrupt 
    (PINT)FLASH_CORRECTABLE_ERROR_ISR,                      // 12.11 - Flash Correctable Error Interrupt 
    (PINT)RAM_ACCESS_VIOLATION_ISR,                         // 12.12 - RAM Access Violation Interrupt 
    (PINT)SYS_PLL_SLIP_ISR,                                 // 12.13 - System PLL Slip Interrupt 
    (PINT)AUX_PLL_SLIP_ISR,                                 // 12.14 - Auxiliary PLL Slip Interrupt 
    (PINT)CLA_OVERFLOW_ISR,                                 // 12.15 - CLA Overflow Interrupt 
    (PINT)CLA_UNDERFLOW_ISR                                 // 12.16 - CLA Underflow Interrupt 
};

//This function initializes the PIE vector table to a known state.This function must be executed after boot time.
void	Class_SysDrv::Drv_InitPieVectTable(void)
{
	Uint16	i;	
	Uint32	*Source  =	(Uint32  *)  &PieVectTableInit;
	Uint32	*Dest  =  (Uint32  *)  &PieVectTable;

// Do not write over first 3 32-bit locations (these locations are
// initialized by Boot ROM with boot variables)

	Source	=  Source  +  3;  
	Dest  =  Dest  +  3;  

	EALLOW;  
	for(i  =  0;  i  <	221;  i++)	
	{  
	*Dest++  =	*Source++;	
	}  
	EDIS;  

// Enable the PIE Vector Table
	PieCtrlRegs.PIECTRL.bit.ENPIE  =  1;
}



	
		
void	Class_SysDrv::Drv_InitPIE(void)
{
		DINT;
	
	// Initialize the PIE control registers to their default state.
	// The default state is all PIE interrupts disabled and flags
	// are cleared.
		objSysDrv.Drv_InitPieCtrl();
	
		// Disable CPU interrupts and clear all CPU interrupt flags:
		IER = 0x0000;
		IFR = 0x0000;
	
		// Initialize the PIE vector table with pointers to the shell Interrupt Service Routines (ISR).
		// This will populate the entire table, even if the interrupt
		objSysDrv.Drv_InitPieVectTable();
	

}


//This function enable the PIE module and CPU interrupts
void	Class_SysDrv::Drv_InitInterrupts(void)					
{
		//EALLOW;

		//PieVectTable.EPWM1_INT = &EPWM_INT_ISR;
		//PieVectTable.CANA0_INT = &ECAN0INTA_ISR;
		//PieVectTable.ILLEGAL_INT = &ILLEGAL_ISR;

		
		EDIS;
	
		// Enable the PWM interrupt on the processor (PIE).
		PieCtrlRegs.PIEIER3.bit.INTx1 = 1;
  		//PieCtrlRegs.PIEIER9.bit.INTx5 = 1;          // Enable eCAN A0		
		IER |= (M_INT3); // Enable CPU INT3 INT9 and clear all CPU interrupt flags:

}


//============================================================
// End of file.
//============================================================
